SatisfiedRequest

Enum SatisfiedRequest 

pub enum SatisfiedRequest {
Show 21 variants Header { req: Header, resp: <Header as Request>::Response, }, HeaderWithProof { req: HeaderWithProof, resp: <HeaderWithProof as Request>::Response, }, Headers { req: Headers, resp: <Headers as Request>::Response, }, HeadersWithCheckpoint { req: HeadersWithCheckpoint, resp: <HeadersWithCheckpoint as Request>::Response, }, EstimateFee { req: EstimateFee, resp: <EstimateFee as Request>::Response, }, HeadersSubscribe { req: HeadersSubscribe, resp: <HeadersSubscribe as Request>::Response, }, RelayFee { req: RelayFee, resp: <RelayFee as Request>::Response, }, GetBalance { req: GetBalance, resp: <GetBalance as Request>::Response, }, GetHistory { req: GetHistory, resp: <GetHistory as Request>::Response, }, GetMempool { req: GetMempool, resp: <GetMempool as Request>::Response, }, ListUnspent { req: ListUnspent, resp: <ListUnspent as Request>::Response, }, ScriptHashSubscribe { req: ScriptHashSubscribe, resp: <ScriptHashSubscribe as Request>::Response, }, ScriptHashUnsubscribe { req: ScriptHashUnsubscribe, resp: <ScriptHashUnsubscribe as Request>::Response, }, BroadcastTx { req: BroadcastTx, resp: <BroadcastTx as Request>::Response, }, GetTx { req: GetTx, resp: <GetTx as Request>::Response, }, GetTxMerkle { req: GetTxMerkle, resp: <GetTxMerkle as Request>::Response, }, GetTxidFromPos { req: GetTxidFromPos, resp: <GetTxidFromPos as Request>::Response, }, GetFeeHistogram { req: GetFeeHistogram, resp: <GetFeeHistogram as Request>::Response, }, Banner { req: Banner, resp: <Banner as Request>::Response, }, Ping { req: Ping, resp: <Ping as Request>::Response, }, Custom { req: Custom, resp: <Custom as Request>::Response, },
}
A successfully handled request and its decoded server response.

This enum is returned when a request has been fully processed and the server replied with a valid result. It contains both the original request and the corresponding response.

SatisfiedRequest is used by the Event::Response variant to expose typed request-response pairs to the caller.

You typically don’t construct this manually — it is created internally by the client after decoding JSON-RPC responses.

Variants



Header

Fields



HeaderWithProof



Headers

Fields



HeadersWithCheckpoint



EstimateFee



HeadersSubscribe



RelayFee

Fields



GetBalance



GetHistory



GetMempool



ListUnspent



ScriptHashSubscribe



ScriptHashUnsubscribe



BroadcastTx



GetTx

Fields

req: GetTx


GetTxMerkle



GetTxidFromPos



GetFeeHistogram



Banner

Fields



Ping

Fields

req: Ping
resp: <Ping as Request>::Response


Custom

Fields