AsyncEventSender

Type Alias AsyncEventSender 

pub type AsyncEventSender = UnboundedSender<Event>;
The sending half of the internal event stream, used to emit Events from the client worker loop.

Aliased Type

pub struct AsyncEventSender(/* private fields */);