pub struct EstimateFee {
pub number: usize,
}Expand description
A request for an estimated fee rate needed to confirm a transaction within a target number of blocks.
This corresponds to the "blockchain.estimatefee" Electrum RPC method. It returns the estimated
fee rate (in BTC per kilobyte) required to be included within the specified number of blocks.
See: https://electrum-protocol.readthedocs.io/en/latest/protocol-methods.html#blockchain-estimatefee
Fields
number: usizeThe number of blocks to target for confirmation.